==> qxmledit-0.9.3-src.tgz: qxmledit-0.9.3/test/testhelpers/editelementtest.cpp <==
/**************************************************************************
 *  This file is part of QXmlEdit                                         *
 *  Copyright (C) 2014 by Luca Bellonda and individual contributors       *
 *    as indicated in the AUTHORS file                                    *
 *  lbellonda _at_ gmail.com                                              *
 *                                                                        *
 * This library is free software; you can redistribute it and/or          *
 * modify it under the terms of the GNU Library General Public            *
 * License as published by the Free Software Foundation; either           *
 * version 2 of the License, or (at your option) any later version.       *
 *                                                                        *
 * This library is distributed in the hope that it will be useful,        *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 * Library General Public License for more details.                       *
 *                                                                        *
 * You should have received a copy of the GNU Library General Public      *
 * License along with this library; if not, write to the                  *
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
 * Boston, MA  02110-1301  USA                                            *
 **************************************************************************/


#include "editelementtest.h"

EditElementTest::EditElementTest(QWidget * parent) : EditElement(parent)
{
}

EditElementTest::~EditElementTest()
{
}

AttributeColumnItemDelegate *EditElementTest::attributeDelegate()
{
    return _attributeDelegate;
}

int EditElementTest::columnForEditAttributes()
{
    return A_COLUMN_TEXT;
}

bool EditElementTest::testApplyNamespaceOper(NamespaceCommands *commands)
{
    applyNamespaceOper(commands);
    return updateTarget(target);
}

==> qxmledit-0.9.9.2-src.tgz: qxmledit-0.9.9.2/test/testhelpers/editelementtest.cpp <==
/**************************************************************************
 *  This file is part of QXmlEdit                                         *
 *  Copyright (C) 2014 by Luca Bellonda and individual contributors       *
 *    as indicated in the AUTHORS file                                    *
 *  lbellonda _at_ gmail.com                                              *
 *                                                                        *
 * This library is free software; you can redistribute it and/or          *
 * modify it under the terms of the GNU Library General Public            *
 * License as published by the Free Software Foundation; either           *
 * version 2 of the License, or (at your option) any later version.       *
 *                                                                        *
 * This library is distributed in the hope that it will be useful,        *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 * Library General Public License for more details.                       *
 *                                                                        *
 * You should have received a copy of the GNU Library General Public      *
 * License along with this library; if not, write to the                  *
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
 * Boston, MA  02110-1301  USA                                            *
 **************************************************************************/


#include "editelementtest.h"

EditElementTest::EditElementTest(QWidget * parent) : EditElement(parent)
{
}

EditElementTest::~EditElementTest()
{
}

AttributeColumnItemDelegate *EditElementTest::attributeDelegate()
{
    return _attributeTextDelegate;
}

int EditElementTest::columnForEditAttributes()
{
    return A_COLUMN_TEXT;
}

bool EditElementTest::testApplyNamespaceOper(NamespaceCommands *commands)
{
    applyNamespaceOper(commands);
    return updateTarget(target);
}
